@@ -3,6 +3,7 @@ import datetime
 import odoo
 import pytz
 from odoo.http import request
+from odoo import models
 
 UNNECESSARY_FIELDS = [
     'activity_ids', 'activity_state', 'activity_user_id', 'activity_type_id', 'activity_type_icon',
@@ -16,7 +17,7 @@ UNNECESSARY_FIELDS = [
 ]
 
 
-def fields_extractor(model_object: list, remove_fields=None):
+def fields_extractor(model_object: models.Model, remove_fields=None):
     if remove_fields is None:
         remove_fields = UNNECESSARY_FIELDS
     result = []
@@ -54,9 +55,9 @@ def read_serializer(value_object):
         one_record = {}
         for v in list(value.keys()):
             if isinstance(value[v], datetime.date):
-                one_record[v] = datetime_toString(value[v]) or None
+                one_record[v] = odoo.fields.Date.to_string(value[v]) or None
             elif isinstance(value[v], datetime.datetime):
-                one_record[v] = odoo.fields.Datetime.to_string(value[v]) or None
+                one_record[v] = datetime_toString(value[v]) or None
             elif isinstance(value[v], tuple):
                 one_record[v] = {'id': value[v][0], 'name': value[v][1]} or None
             else:
@@ -66,4 +67,4 @@ def read_serializer(value_object):
 
 
 def datetime_toString(date_object):
-        return date_object.astimezone(pytz.timezone(request.env.user.tz or pytz.utc))
+    return date_object.astimezone(pytz.timezone(request.env.user.tz or pytz.utc))
