@@ -12,6 +12,12 @@ def dict_body_data(**kwargs):
     except Exception as e:
         kwargs['message'] = str(e)
     finally:
+        for k in kwargs:
+            print(k)
+            try:
+                kwargs[k] = int(kwargs[k])
+            except:
+                pass
         return kwargs
 
 
@@ -32,3 +38,18 @@ def login_required(route=None, **kwargs):
         return wrapper
 
     return decorator
+
+
+def public_route(route=None, **kwargs):
+    def decorator(view_func):
+        @functools.wraps(view_func)
+        @http.route(route, **kwargs)
+        def wrapper(self, **kw):
+            kw.update(dict_body_data(**kw))
+            if kw.get('message'):
+                return jwt_http.errcode(code=500, message=kw['message'])
+            return view_func(self, **kw)
+
+        return wrapper
+
+    return decorator
